@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 
-our $VERSION = '0.1600';
+our $VERSION = '0.1601';
 
 use parent 'Games::Solitaire::Verify::Base';
 
@@ -121,13 +121,14 @@ sub to_string
     my $self = shift;
 
     my $ret = "Freecells:" . (($self->count() == 0) ? "" :
-    join("",
-        map { "  " . (defined($_) ? $_->fast_s() : "  ") }
-        map { $self->cell($_) }
-        (0 .. ($self->count()-1))
-    ));
+        join("",
+            map { "  " . (defined($_) ? $_->fast_s() : "  ") }
+            map { $self->cell($_) }
+            (0 .. ($self->count()-1))
+        ));
+    $ret =~ s# +\z##;
 
-    return ($ret =~ s# +\z##r);
+    return $ret;
 }
 
 
@@ -203,7 +204,7 @@ Freecells in games such as Freecell, Baker's Game, or Seahaven Towers
 
 =head1 VERSION
 
-version 0.1600
+version 0.1601
 
 =head1 SYNOPSIS
 
