@@ -26,9 +26,12 @@ sub _l
     # We use this instead of the accessor for speed.
     $s->{_ln}++;
 
-    my $ret = scalar (readline($s->{_i}));
-
-    return defined($ret) ? ($ret =~ s# +(\n?)\z#$1#r) : $ret;
+    my $ret;
+    if (defined ( $ret = scalar (readline($s->{_i})) ))
+    {
+        $ret =~ s# +(\n?)\z#$1#;
+    }
+    return $ret;
 }
 
 1;
@@ -46,7 +49,7 @@ all Games::Solitaire::Verify::Solution::* classes.
 
 =head1 VERSION
 
-version 0.1600
+version 0.1601
 
 =head1 AUTHOR
 
